# coding: utf-8

"""
    RCABench API

    RCABench - A comprehensive root cause analysis benchmarking platform for microservices This API provides endpoints for managing datasets, algorithms, evaluations, and fault injections for root cause analysis in distributed systems and microservices architectures.

    The version of the OpenAPI document: 1.0.1
    Contact: team@rcabench.com
    Generated by OpenAPI Generator (https://rcabench.openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class DtoFilterOperator(str, Enum):
    """
    DtoFilterOperator
    """

    """
    allowed enum values
    """
    OpEqual = 'eq'
    OpNotEqual = 'ne'
    OpGreater = 'gt'
    OpGreaterEq = 'gte'
    OpLess = 'lt'
    OpLessEq = 'lte'
    OpLike = 'like'
    OpStartsWith = 'starts'
    OpEndsWith = 'ends'
    OpNotLike = 'nlike'
    OpIn = 'in'
    OpNotIn = 'nin'
    OpIsNull = 'null'
    OpIsNotNull = 'nnull'
    OpDateEqual = 'deq'
    OpDateAfter = 'dafter'
    OpDateBefore = 'dbefore'
    OpDateBetween = 'dbetween'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of DtoFilterOperator from a JSON string"""
        return cls(json.loads(json_str))


