# coding: utf-8

"""
    RCABench API

    RCABench - A comprehensive root cause analysis benchmarking platform for microservices This API provides endpoints for managing datasets, algorithms, evaluations, and fault injections for root cause analysis in distributed systems and microservices architectures.

    The version of the OpenAPI document: 1.0.1
    Contact: team@rcabench.com
    Generated by OpenAPI Generator (https://rcabench.openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from rcabench.openapi.models.database_task import DatabaseTask
from rcabench.openapi.models.handler_groundtruth import HandlerGroundtruth
from typing import Optional, Set
from typing_extensions import Self

class DtoQueryInjectionResp(BaseModel):
    """
    DtoQueryInjectionResp
    """ # noqa: E501
    benchmark: Optional[StrictStr] = Field(default=None, description="基准数据库，添加索引")
    created_at: Optional[StrictStr] = Field(default=None, description="创建时间，添加时间索引")
    description: Optional[StrictStr] = Field(default=None, description="描述（可选字段）")
    display_config: Optional[StrictStr] = Field(default=None, description="面向用户的展示配置")
    end_time: Optional[StrictStr] = Field(default=None, description="预计故障结束时间，添加时间索引")
    engine_config: Optional[StrictStr] = Field(default=None, description="面向系统的运行配置")
    fault_type: Optional[StrictInt] = Field(default=None, description="故障类型，添加复合索引")
    ground_truth: Optional[HandlerGroundtruth] = None
    id: Optional[StrictInt] = Field(default=None, description="唯一标识")
    injection_name: Optional[StrictStr] = Field(default=None, description="在k8s资源里注入的名字")
    pre_duration: Optional[StrictInt] = Field(default=None, description="正常数据时间")
    start_time: Optional[StrictStr] = Field(default=None, description="预计故障开始时间，添加时间索引")
    status: Optional[StrictInt] = Field(default=None, description="状态，添加复合索引")
    task: Optional[DatabaseTask] = Field(default=None, description="外键关联")
    task_id: Optional[StrictStr] = Field(default=None, description="从属什么 taskid，添加复合索引")
    updated_at: Optional[StrictStr] = Field(default=None, description="更新时间")
    additional_properties: Dict[str, Any] = {}
    __properties: ClassVar[List[str]] = ["benchmark", "created_at", "description", "display_config", "end_time", "engine_config", "fault_type", "ground_truth", "id", "injection_name", "pre_duration", "start_time", "status", "task", "task_id", "updated_at"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of DtoQueryInjectionResp from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * Fields in `self.additional_properties` are added to the output dict.
        """
        excluded_fields: Set[str] = set([
            "additional_properties",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of ground_truth
        if self.ground_truth:
            _dict['ground_truth'] = self.ground_truth.to_dict()
        # override the default output from pydantic by calling `to_dict()` of task
        if self.task:
            _dict['task'] = self.task.to_dict()
        # puts key-value pairs in additional_properties in the top level
        if self.additional_properties is not None:
            for _key, _value in self.additional_properties.items():
                _dict[_key] = _value

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of DtoQueryInjectionResp from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "benchmark": obj.get("benchmark"),
            "created_at": obj.get("created_at"),
            "description": obj.get("description"),
            "display_config": obj.get("display_config"),
            "end_time": obj.get("end_time"),
            "engine_config": obj.get("engine_config"),
            "fault_type": obj.get("fault_type"),
            "ground_truth": HandlerGroundtruth.from_dict(obj["ground_truth"]) if obj.get("ground_truth") is not None else None,
            "id": obj.get("id"),
            "injection_name": obj.get("injection_name"),
            "pre_duration": obj.get("pre_duration"),
            "start_time": obj.get("start_time"),
            "status": obj.get("status"),
            "task": DatabaseTask.from_dict(obj["task"]) if obj.get("task") is not None else None,
            "task_id": obj.get("task_id"),
            "updated_at": obj.get("updated_at")
        })
        # store additional fields in additional_properties
        for _key in obj.keys():
            if _key not in cls.__properties:
                _obj.additional_properties[_key] = obj.get(_key)

        return _obj


