# coding: utf-8

"""
    RCABench API

    RCABench - A comprehensive root cause analysis benchmarking platform for microservices This API provides endpoints for managing datasets, algorithms, evaluations, and fault injections for root cause analysis in distributed systems and microservices architectures.

    The version of the OpenAPI document: 1.0.1
    Contact: team@rcabench.com
    Generated by OpenAPI Generator (https://rcabench.openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from rcabench.openapi.models.database_label import DatabaseLabel
from rcabench.openapi.models.database_project import DatabaseProject
from rcabench.openapi.models.dto_dataset_v2_injection_relation_response import DtoDatasetV2InjectionRelationResponse
from typing import Optional, Set
from typing_extensions import Self

class DtoDatasetV2Response(BaseModel):
    """
    DtoDatasetV2Response
    """ # noqa: E501
    checksum: Optional[StrictStr] = Field(default=None, description="文件校验和")
    created_at: Optional[StrictStr] = Field(default=None, description="创建时间")
    data_source: Optional[StrictStr] = Field(default=None, description="数据来源描述")
    description: Optional[StrictStr] = Field(default=None, description="数据集描述")
    download_url: Optional[StrictStr] = Field(default=None, description="下载链接")
    file_count: Optional[StrictInt] = Field(default=None, description="文件数量")
    format: Optional[StrictStr] = Field(default=None, description="数据格式")
    id: Optional[StrictInt] = Field(default=None, description="唯一标识")
    injections: Optional[List[DtoDatasetV2InjectionRelationResponse]] = Field(default=None, description="关联的故障注入")
    is_public: Optional[StrictBool] = Field(default=None, description="是否公开")
    labels: Optional[List[DatabaseLabel]] = Field(default=None, description="关联的标签")
    name: Optional[StrictStr] = Field(default=None, description="数据集名称")
    project: Optional[DatabaseProject] = Field(default=None, description="关联项目信息")
    project_id: Optional[StrictInt] = Field(default=None, description="项目ID")
    status: Optional[StrictInt] = Field(default=None, description="状态")
    type: Optional[StrictStr] = Field(default=None, description="数据集类型")
    updated_at: Optional[StrictStr] = Field(default=None, description="更新时间")
    version: Optional[StrictStr] = Field(default=None, description="数据集版本")
    additional_properties: Dict[str, Any] = {}
    __properties: ClassVar[List[str]] = ["checksum", "created_at", "data_source", "description", "download_url", "file_count", "format", "id", "injections", "is_public", "labels", "name", "project", "project_id", "status", "type", "updated_at", "version"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of DtoDatasetV2Response from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * Fields in `self.additional_properties` are added to the output dict.
        """
        excluded_fields: Set[str] = set([
            "additional_properties",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in injections (list)
        _items = []
        if self.injections:
            for _item_injections in self.injections:
                if _item_injections:
                    _items.append(_item_injections.to_dict())
            _dict['injections'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in labels (list)
        _items = []
        if self.labels:
            for _item_labels in self.labels:
                if _item_labels:
                    _items.append(_item_labels.to_dict())
            _dict['labels'] = _items
        # override the default output from pydantic by calling `to_dict()` of project
        if self.project:
            _dict['project'] = self.project.to_dict()
        # puts key-value pairs in additional_properties in the top level
        if self.additional_properties is not None:
            for _key, _value in self.additional_properties.items():
                _dict[_key] = _value

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of DtoDatasetV2Response from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "checksum": obj.get("checksum"),
            "created_at": obj.get("created_at"),
            "data_source": obj.get("data_source"),
            "description": obj.get("description"),
            "download_url": obj.get("download_url"),
            "file_count": obj.get("file_count"),
            "format": obj.get("format"),
            "id": obj.get("id"),
            "injections": [DtoDatasetV2InjectionRelationResponse.from_dict(_item) for _item in obj["injections"]] if obj.get("injections") is not None else None,
            "is_public": obj.get("is_public"),
            "labels": [DatabaseLabel.from_dict(_item) for _item in obj["labels"]] if obj.get("labels") is not None else None,
            "name": obj.get("name"),
            "project": DatabaseProject.from_dict(obj["project"]) if obj.get("project") is not None else None,
            "project_id": obj.get("project_id"),
            "status": obj.get("status"),
            "type": obj.get("type"),
            "updated_at": obj.get("updated_at"),
            "version": obj.get("version")
        })
        # store additional fields in additional_properties
        for _key in obj.keys():
            if _key not in cls.__properties:
                _obj.additional_properties[_key] = obj.get(_key)

        return _obj


